Skip to contents

print method for class 'jmrmlB'

Usage

# S3 method for jmrmlB
print(x, ...)

Arguments

x

fitted object

...

others

Value

prints table containing various parameter estimates, SE, P- value for both survival and longitudinal submodel, if the model is bayesian it includes their credible interval too.