print.jmrmlB.Rd
print method for class 'jmrmlB'
# S3 method for jmrmlB print(x, ...)
fitted object
others
prints table containing various parameter estimates, SE, P- value for both survival and longitudinal submodel, if the model is bayesian it includes their credible interval too.